@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_iotevents.type_defs import (
@@ -58,14 +59,15 @@ class Exceptions:
 
 class IoTEventsClient:
     """
-    [IoTEvents.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client)
+    [IoTEvents.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.can_paginate)
         """
 
     def create_detector_model(
@@ -79,7 +81,7 @@ class IoTEventsClient:
         evaluationMethod: Literal["BATCH", "SERIAL"] = None,
     ) -> CreateDetectorModelResponseTypeDef:
         """
-        [Client.create_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.create_detector_model)
+        [Client.create_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.create_detector_model)
         """
 
     def create_input(
@@ -90,34 +92,34 @@ class IoTEventsClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateInputResponseTypeDef:
         """
-        [Client.create_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.create_input)
+        [Client.create_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.create_input)
         """
 
     def delete_detector_model(self, detectorModelName: str) -> Dict[str, Any]:
         """
-        [Client.delete_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.delete_detector_model)
+        [Client.delete_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.delete_detector_model)
         """
 
     def delete_input(self, inputName: str) -> Dict[str, Any]:
         """
-        [Client.delete_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.delete_input)
+        [Client.delete_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.delete_input)
         """
 
     def describe_detector_model(
         self, detectorModelName: str, detectorModelVersion: str = None
     ) -> DescribeDetectorModelResponseTypeDef:
         """
-        [Client.describe_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.describe_detector_model)
+        [Client.describe_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.describe_detector_model)
         """
 
     def describe_input(self, inputName: str) -> DescribeInputResponseTypeDef:
         """
-        [Client.describe_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.describe_input)
+        [Client.describe_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.describe_input)
         """
 
     def describe_logging_options(self) -> DescribeLoggingOptionsResponseTypeDef:
         """
-        [Client.describe_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.describe_logging_options)
+        [Client.describe_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.describe_logging_options)
         """
 
     def generate_presigned_url(
@@ -128,48 +130,48 @@ class IoTEventsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.generate_presigned_url)
         """
 
     def list_detector_model_versions(
         self, detectorModelName: str, nextToken: str = None, maxResults: int = None
     ) -> ListDetectorModelVersionsResponseTypeDef:
         """
-        [Client.list_detector_model_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.list_detector_model_versions)
+        [Client.list_detector_model_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.list_detector_model_versions)
         """
 
     def list_detector_models(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListDetectorModelsResponseTypeDef:
         """
-        [Client.list_detector_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.list_detector_models)
+        [Client.list_detector_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.list_detector_models)
         """
 
     def list_inputs(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListInputsResponseTypeDef:
         """
-        [Client.list_inputs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.list_inputs)
+        [Client.list_inputs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.list_inputs)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.list_tags_for_resource)
         """
 
     def put_logging_options(self, loggingOptions: "LoggingOptionsTypeDef") -> None:
         """
-        [Client.put_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.put_logging_options)
+        [Client.put_logging_options documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.put_logging_options)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.untag_resource)
         """
 
     def update_detector_model(
@@ -181,7 +183,7 @@ class IoTEventsClient:
         evaluationMethod: Literal["BATCH", "SERIAL"] = None,
     ) -> UpdateDetectorModelResponseTypeDef:
         """
-        [Client.update_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.update_detector_model)
+        [Client.update_detector_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.update_detector_model)
         """
 
     def update_input(
@@ -191,5 +193,5 @@ class IoTEventsClient:
         inputDescription: str = None,
     ) -> UpdateInputResponseTypeDef:
         """
-        [Client.update_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.10/reference/services/iotevents.html#IoTEvents.Client.update_input)
+        [Client.update_input documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/iotevents.html#IoTEvents.Client.update_input)
         """
